@@ -27,6 +27,8 @@
  * See README
  */
 
+#define WE_ARE_LIBGNOMEPRINT_INTERNALS /* Needed for gpa-tree-viewer which is not public */
+
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #include <libgnomeprint/gnome-print-config.h>
@@ -34,6 +36,7 @@
 #include <libgnomeprintui/gnome-print-dialog.h>
 #include <libgnomeprintui/gnome-print-paper-selector.h>
 #include <libgnomeprintui/gnome-font-dialog.h>
+#include <libgnomeprintui/gpaui/gpa-tree-viewer.h>
 
 #include <gtk/gtk.h>
 #include <glade/glade.h>
@@ -135,8 +138,9 @@ my_print (GnomePrintJob *job, gboolean preview)
 	gpc = gnome_print_job_get_context (job);
 	my_draw (gpc);
 	g_object_unref (G_OBJECT (gpc));
-	gnome_print_job_close (job);
 	
+	gnome_print_job_close (job);
+
 	if (!preview) {
 		my_status_bar_print ("Printing ...");
 		gnome_print_job_print (job);
@@ -172,7 +176,7 @@ my_print_cb (void)
 		return;
 	}
 
-	g_object_unref (job);
+	g_object_unref (G_OBJECT (job));
 }
 
 static void
